@@ -191,7 +191,7 @@ class BaseManager(models.Manager):
 
             return retval
 
-    def get_or_create(self, **kwargs):
+    def get_or_create(self, _cache=False, **kwargs):
         """
         A modified version of Django's get_or_create which will create a distributed
         lock (using the cache backend) whenever it hits the create clause.
@@ -200,6 +200,8 @@ class BaseManager(models.Manager):
 
         # before locking attempt to fetch the instance
         try:
+            if _cache:
+                return self.get_from_cache(**kwargs), False
             return self.get(**kwargs), False
         except self.model.DoesNotExist:
             pass
@@ -402,8 +404,8 @@ class GroupManager(BaseManager, ChartMixin):
                 path = '%s.%s' % (viewhandler.__module__, viewhandler.__class__.__name__)
 
                 if not viewhandler.ref:
-                    # TODO: this should handle race conditions
                     viewhandler.ref = View.objects.get_or_create(
+                        _cache=True,
                         path=path,
                         defaults=dict(
                             verbose_name=viewhandler.verbose_name,
@@ -546,16 +548,9 @@ class GroupManager(BaseManager, ChartMixin):
             defaults=update_kwargs
         )
 
-        http = event.interfaces.get('sentry.interfaces.Http')
-        if http:
-            url = http.url
-        else:
-            url = None
-
         for key, value in (
                 ('server_name', event.server_name),
                 ('site', event.site),
-                ('url', url),
                 ('logger', event.logger),
             ):
             if not value:
@@ -567,20 +562,15 @@ class GroupManager(BaseManager, ChartMixin):
                 value=value,
             )
 
-            affected = group.messagefiltervalue_set.filter(
+            group.messagefiltervalue_set.create_or_update(
                 project=project,
                 key=key,
                 value=value,
-            ).update(times_seen=F('times_seen') + 1, last_seen=date)
-            if not affected:
-                group.messagefiltervalue_set.create(
-                    project=project,
-                    key=key,
-                    value=value,
-                    times_seen=1,
+                defaults=dict(
+                    times_seen=F('times_seen') + 1,
                     last_seen=date,
-                    first_seen=date,
                 )
+            )
 
         return group, is_new, is_sample
 
